SystemOrganization addCategory: #'Arduino-Compiler-Uploading'!
SystemOrganization addCategory: #'Arduino-Compiler-BoardTypes'!

Object subclass: #ArduinoSketchUploader
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-Uploading'!

!ArduinoSketchUploader commentStamp: 'Richo 3/9/2010 12:57' prior: 0!
I'm responsible for uploading sketches to the Arduino board. My protocol is very simple: #uploadSketchNamed:onPort:arduinoType:

To accomplish this task I need a specific directory tree:

.\Arduino
.\Arduino\hardware
.\Arduino\hardware\cores
.\Arduino\hardware\cores\arduino 
	"Contains the arduino source code (needed for compilation)"
.\Arduino\hardware\libraries
	"Contains all the needed libraries in separate folders"
.\Arduino\hardware\tools\
.\Arduino\hardware\tools\avr\
	"Contains the avr installation"
.\Arduino\Sketches
	"Contains the source code we are going to compile and upload"

Apart from that, I need a batch file called "upload.bat" in the sketches directory (.\Arduino\Sketches). This file is the responsible for calling make with the correct parameters, I simply execute it and hope for the best. 
Also, each sketch must have its own folder with a proper Makefile. The sketch folder must have the same name as the sketch. For instance, if I have a sketch named "Blink.pde" I must put it in ".\Arduino\Sketches\Blink". Otherwise, it won't compile.

!

!ArduinoSketchUploader class methodsFor: 'as yet unclassified' stamp: 'Richo 3/5/2010 17:51'!
makefile
^'# Arduino 0015 Makefile
# Arduino adaptation by mellis, eighthave, oli.keller
#
# This makefile allows you to build sketches from the command line
# without the Arduino environment (or Java).
#
# Detailed instructions for using the makefile:
#
#  1. Copy this file into the folder with your sketch. There should be a
#     file with the same name as the folder and with the extension .pde
#     (e.g. foo.pde in the foo/ folder).
#
#  2. Modify the line containg "INSTALL_DIR" to point to the directory that
#     contains the Arduino installation (for example, under Mac OS X, this
#     might be /Applications/arduino-0012).
#
#  3. Modify the line containing "PORT" to refer to the filename
#     representing the USB or serial connection to your Arduino board
#     (e.g. PORT = /dev/tty.USB0).  If the exact name of this file
#     changes, you can use * as a wildcard (e.g. PORT = /dev/tty.usb*).
#
#  4. Set the line containing "MCU" to match your board''s processor. 
#     Older one''s are atmega8 based, newer ones like Arduino Mini, Bluetooth
#     or Diecimila have the atmega168.  If you''re using a LilyPad Arduino,
#     change F_CPU to 8000000.
#
#  5. At the command line, change to the directory containing your
#     program''file and the makefile.
#
#  6. Type "make" and press enter to compile/verify your program.
#
#  7. Type "make upload", reset your Arduino board, and press enter to
#     upload your program to the Arduino board.
#
# $Id$

TARGET = Blink
INSTALL_DIR = ../..
PORT = com6
UPLOAD_RATE = 57600
AVRDUDE_PROGRAMMER = stk500
MCU = atmega328p
F_CPU = 16000000

############################################################################
# Below here nothing should be changed...

ARDUINO = $(INSTALL_DIR)/hardware/cores/arduino
AVR_TOOLS_PATH = $(INSTALL_DIR)/hardware/tools/avr/bin
SRC =  $(ARDUINO)/pins_arduino.c $(ARDUINO)/wiring.c \
$(ARDUINO)/wiring_analog.c $(ARDUINO)/wiring_digital.c \
$(ARDUINO)/wiring_pulse.c \
$(ARDUINO)/wiring_shift.c $(ARDUINO)/WInterrupts.c
CXXSRC = $(ARDUINO)/HardwareSerial.cpp $(ARDUINO)/WMath.cpp \
$(ARDUINO)/Print.cpp
FORMAT = ihex


# Name of this Makefile (used for "make depend").
MAKEFILE = Makefile

# Debugging format.
# Native formats for AVR-GCC''-g are stabs [default], or dwarf-2.
# AVR (extended) COFF requires stabs, plus an avr-objcopy run.
DEBUG = stabs

OPT = s

# Place -D or -U options here
CDEFS = -DF_CPU=$(F_CPU)
CXXDEFS = -DF_CPU=$(F_CPU)

# Place -I options here
CINCS = -I$(ARDUINO)
CXXINCS = -I$(ARDUINO)

# Compiler flag to set the C Standard level.
# c89   - "ANSI" C
# gnu89 - c89 plus GCC extensions
# c99   - ISO C99 standard (not yet fully implemented)
# gnu99 - c99 plus GCC extensions
CSTANDARD = -std=gnu99
CDEBUG = -g$(DEBUG)
CWARN = -Wall -Wstrict-prototypes
CTUNING = -funsigned-char -funsigned-bitfields -fpack-struct -fshort-enums
#CEXTRA = -Wa,-adhlns=$(<:.c=.lst)

CFLAGS = $(CDEBUG) $(CDEFS) $(CINCS) -O$(OPT) $(CWARN) $(CSTANDARD) $(CEXTRA)
CXXFLAGS = $(CDEFS) $(CINCS) -O$(OPT)
#ASFLAGS = -Wa,-adhlns=$(<:.S=.lst),-gstabs 
LDFLAGS = -lm


# Programming support using avrdude. Settings and variables.
AVRDUDE_PORT = $(PORT)
AVRDUDE_WRITE_FLASH = -U flash:w:applet/$(TARGET).hex
AVRDUDE_FLAGS = -V -F -C $(INSTALL_DIR)/hardware/tools/avr/etc/avrdude.conf \
-p $(MCU) -P $(AVRDUDE_PORT) -c $(AVRDUDE_PROGRAMMER) \
-b $(UPLOAD_RATE)

# Program settings
CC = $(AVR_TOOLS_PATH)/avr-gcc
CXX = $(AVR_TOOLS_PATH)/avr-g++
OBJCOPY = $(AVR_TOOLS_PATH)/avr-objcopy
OBJDUMP = $(AVR_TOOLS_PATH)/avr-objdump
AR  = $(AVR_TOOLS_PATH)/avr-ar
SIZE = $(AVR_TOOLS_PATH)/avr-size
NM = $(AVR_TOOLS_PATH)/avr-nm
AVRDUDE = $(AVR_TOOLS_PATH)/avrdude
REMOVE = rm -f
MV = mv -f

# Define all object files.
OBJ = $(SRC:.c=.o) $(CXXSRC:.cpp=.o) $(ASRC:.S=.o) 

# Define all listing files.
LST = $(ASRC:.S=.lst) $(CXXSRC:.cpp=.lst) $(SRC:.c=.lst)

# Combine all necessary flags and optional flags.
# Add target processor to flags.
ALL_CFLAGS = -mmcu=$(MCU) -I. $(CFLAGS)
ALL_CXXFLAGS = -mmcu=$(MCU) -I. $(CXXFLAGS)
ALL_ASFLAGS = -mmcu=$(MCU) -I. -x assembler-with-cpp $(ASFLAGS)


# Default target.
all: applet_files build sizeafter

build: elf hex 

applet_files: $(TARGET).pde
	# Here is the "preprocessing".
	# It creates a .cpp file based with the same name as the .pde file.
	# On top of the new .cpp file comes the WProgram.h header.
	# At the end there is a generic main() function attached.
	# Then the .cpp file will be compiled. Errors during compile will
	# refer to this new, automatically generated, file. 
	# Not the original .pde file you actually edit...
	test -d applet || mkdir applet
	echo ''#include "WProgram.h"''> applet/$(TARGET).cpp 
	cat $(TARGET).pde >> applet/$(TARGET).cpp
	cat $(ARDUINO)/main.cxx >> applet/$(TARGET).cpp

elf: applet/$(TARGET).elf
hex: applet/$(TARGET).hex
eep: applet/$(TARGET).eep
lss: applet/$(TARGET).lss 
sym: applet/$(TARGET).sym

# Program the device.  
upload: applet/$(TARGET).hex
	$(AVRDUDE) $(AVRDUDE_FLAGS) $(AVRDUDE_WRITE_FLASH)


	# Display size of file.
HEXSIZE = $(SIZE) --target=$(FORMAT) applet/$(TARGET).hex
ELFSIZE = $(SIZE)  applet/$(TARGET).elf
sizebefore:
	@if [ -f applet/$(TARGET).elf ]; then echo; echo $(MSG_SIZE_BEFORE); $(HEXSIZE); echo; fi

sizeafter:
	@if [ -f applet/$(TARGET).elf ]; then echo; echo $(MSG_SIZE_AFTER); $(HEXSIZE); echo; fi


# Convert ELF to COFF for use in debugging / simulating in AVR Studio or VMLAB.
COFFCONVERT=$(OBJCOPY) --debugging \
--change-section-address .data-0x800000 \
--change-section-address .bss-0x800000 \
--change-section-address .noinit-0x800000 \
--change-section-address .eeprom-0x810000 


coff: applet/$(TARGET).elf
	$(COFFCONVERT) -O coff-avr applet/$(TARGET).elf $(TARGET).cof


extcoff: $(TARGET).elf
	$(COFFCONVERT) -O coff-ext-avr applet/$(TARGET).elf $(TARGET).cof


.SUFFIXES: .elf .hex .eep .lss .sym

.elf.hex:
	$(OBJCOPY) -O $(FORMAT) -R .eeprom $< $@

.elf.eep:
	-$(OBJCOPY) -j .eeprom --set-section-flags=.eeprom="alloc,load" \
	--change-section-lma .eeprom=0 -O $(FORMAT) $< $@

# Create extended listing file from ELF output file.
.elf.lss:
	$(OBJDUMP) -h -S $< > $@

# Create a symbol table from ELF output file.
.elf.sym:
	$(NM) -n $< > $@

	# Link: create ELF output file from library.
applet/$(TARGET).elf: $(TARGET).pde applet/core.a 
	$(CC) $(ALL_CFLAGS) -o $@ applet/$(TARGET).cpp -L. applet/core.a $(LDFLAGS)

applet/core.a: $(OBJ)
	@for i in $(OBJ); do echo $(AR) rcs applet/core.a $$i; $(AR) rcs applet/core.a $$i; done



# Compile: create object files from C++ source files.
.cpp.o:
	$(CXX) -c $(ALL_CXXFLAGS) $< -o $@ 

# Compile: create object files from C source files.
.c.o:
	$(CC) -c $(ALL_CFLAGS) $< -o $@ 


# Compile: create assembler files from C source files.
.c.s:
	$(CC) -S $(ALL_CFLAGS) $< -o $@


# Assemble: create object files from assembler source files.
.S.o:
	$(CC) -c $(ALL_ASFLAGS) $< -o $@


# Automatic dependencies
%.d: %.c
	$(CC) -M $(ALL_CFLAGS) $< | sed "s;$(notdir $*).o:;$*.o $*.d:;" > $@

%.d: %.cpp
	$(CXX) -M $(ALL_CXXFLAGS) $< | sed "s;$(notdir $*).o:;$*.o $*.d:;" > $@


# Target: clean project.
clean:
	$(REMOVE) applet/$(TARGET).hex applet/$(TARGET).eep applet/$(TARGET).cof applet/$(TARGET).elf \
	applet/$(TARGET).map applet/$(TARGET).sym applet/$(TARGET).lss applet/core.a \
	$(OBJ) $(LST) $(SRC:.c=.s) $(SRC:.c=.d) $(CXXSRC:.cpp=.s) $(CXXSRC:.cpp=.d)

.PHONY:	all build elf hex eep lss sym program coff extcoff clean applet_files sizebefore sizeafter

-include $(SRC:.c=.d)
-include $(CXXSRC:.cpp=.d)'! !

!ArduinoSketchUploader methodsFor: 'compiling and uploading' stamp: 'Richo 3/30/2010 13:59'!
checkForErrorsOn: sketchDirectory
"I read a file named finished to see if the process ended correctly or there was an error"

	| file errorCode |
	file := FileStream fileNamed: (sketchDirectory fullPathFor: 'finished').
	errorCode := file contents.
	file close.
	errorCode asNumber = 1
		ifTrue: [^CompilingSketchError signal]! !

!ArduinoSketchUploader methodsFor: 'directory' stamp: 'Richo 3/5/2010 18:01'!
createMakefileOnDirectoryNamed: directoryName
| file |
	file := FileStream forceNewFileNamed: (	self sketchesDirectory pathName , '\', directoryName ,'\Makefile' ).
	file nextPutAll: self class makefile.
	file close.! !

!ArduinoSketchUploader methodsFor: 'directory' stamp: 'Richo 3/5/2010 18:01'!
createSketchDirectoryNamed: directoryName
(self sketchesDirectory directoryExists: directoryName)
		ifFalse: [self sketchesDirectory createDirectory: directoryName].
	! !

!ArduinoSketchUploader methodsFor: 'directory' stamp: 'Richo 3/5/2010 18:05'!
createSourceFile: fileContents onDirectoryNamed: directoryName
| file |
	file := FileStream forceNewFileNamed: (	self sketchesDirectory pathName , '\', directoryName ,'\', directoryName , '.pde' ).
	file nextPutAll: fileContents.
	file close.! !

!ArduinoSketchUploader methodsFor: 'directory' stamp: 'Richo 3/5/2010 18:04'!
createSourceFileOnDirectoryNamed: directoryName
| file |
	file := FileStream forceNewFileNamed: (	self sketchesDirectory pathName , '\', directoryName ,'\', directoryName , '.pde' ).
	file nextPutAll: self class makefile.
	file close.! !

!ArduinoSketchUploader methodsFor: 'private' stamp: 'Richo 3/30/2010 13:53'!
executeInUnixUploadFor: sketchName onPort: portName uploadRate: uploadRate mcu: mcu fCpu: fCpu avrdudeProgrammer: programmerId 
	"Do not call this, use #uploadSketch:onPort:arduinoType:"
	(Smalltalk
		at: #OSProcess
		ifAbsent: [^ self error: 'OSProcess not installed']) thisOSProcess chDir: 'Arduino/Sketches';
		 command: './upload.sh ' , sketchName , ' ' , portName , ' ' , uploadRate asString , ' ' , mcu , ' ' , fCpu asString , ' ' , programmerId! !

!ArduinoSketchUploader methodsFor: 'private' stamp: 'Richo 3/30/2010 13:35'!
executeInWin32UploadFor: sketchName onPort: portName uploadRate: uploadRate mcu: mcu fCpu: fCpu avrdudeProgrammer: programmerId 
	"Do not call this, use #uploadSketch:onPort:arduinoType:"
	((Smalltalk
			at: #Win32Shell
			ifAbsent: [^ self error: 'FFI not installed']) new
			shellExecute: nil
			lpOperation: 'open'
			lpFile: 'upload.bat'
			lpParameters: sketchName , ' ' , portName , ' ' , uploadRate asString , ' ' , mcu , ' ' , fCpu asString , ' ' , programmerId
			lpDirectory: 'Arduino/Sketches'
			nShowCmd: 0)
			<= 32
		ifTrue: [self error: 'System error']! !

!ArduinoSketchUploader methodsFor: 'private' stamp: 'Richo 3/30/2010 18:13'!
executeUploadFor: sketchName onPort: portName uploadRate: uploadRate mcu: mcu fCpu: fCpu avrdudeProgrammer: programmerId 
	"Do not call this, use #uploadSketch:onPort:arduinoType:"
	Smalltalk platformName = 'unix'
		ifTrue: [^ self
				executeInUnixUploadFor: sketchName
				onPort: portName
				uploadRate: uploadRate
				mcu: mcu
				fCpu: fCpu
				avrdudeProgrammer: programmerId].
	Smalltalk platformName =  'Win32'
		ifTrue: [^ self
				executeInWin32UploadFor: sketchName
				onPort: portName
				uploadRate: uploadRate
				mcu: mcu
				fCpu: fCpu
				avrdudeProgrammer: programmerId].
	^self error: Smalltalk platformName, ' - Platform not supported'! !

!ArduinoSketchUploader methodsFor: 'testing' stamp: 'Richo 1/4/2010 17:14'!
hasMakefile: sketchDirectory 
	^ sketchDirectory
		fileExists: 'Makefile'! !

!ArduinoSketchUploader methodsFor: 'accessing' stamp: 'Richo 1/4/2010 17:13'!
sketchesDirectory
"It is important to keep this structure!!!!"
	^ (FileDirectory default directoryNamed: 'Arduino')
		directoryNamed: 'Sketches'! !

!ArduinoSketchUploader methodsFor: 'accessing' stamp: 'Richo 1/5/2010 12:45'!
timeoutSeconds
^45! !

!ArduinoSketchUploader methodsFor: 'compiling and uploading' stamp: 'Richo 3/5/2010 17:36'!
uploadFirmataOnPort: portName arduinoType: arduinoType 
	self
		uploadSketchNamed: 'StandardFirmata'
		onPort: portName
		arduinoType: arduinoType! !

!ArduinoSketchUploader methodsFor: 'compiling and uploading' stamp: 'Richo 3/5/2010 18:05'!
uploadSketch: anArduinoSketch onPort: portName arduinoType: arduinoType 
	self createSketchDirectoryNamed:	 anArduinoSketch name.
	self createMakefileOnDirectoryNamed: anArduinoSketch name.
	self createSourceFile: (ArduinoCTranslator new translateSketch: anArduinoSketch) onDirectoryNamed: anArduinoSketch name.
	self
		uploadSketchNamed: anArduinoSketch name
		onPort: portName
		uploadRate: arduinoType uploadRate
		mcu: arduinoType mcu
		fCpu: arduinoType fCpu
		avrdudeProgrammer: arduinoType avrdudeProgrammer! !

!ArduinoSketchUploader methodsFor: 'compiling and uploading' stamp: 'Richo 3/9/2010 12:57'!
uploadSketchNamed: sketchName onPort: portName arduinoType: arduinoType 
	"self new uploadSketchNamed: 'Blink'
	onPort: 'COM6'
	arduinoType: ArduinoATmega328" 
	self
		uploadSketchNamed: sketchName
		onPort: portName
		uploadRate: arduinoType uploadRate
		mcu: arduinoType mcu
		fCpu: arduinoType fCpu
		avrdudeProgrammer: arduinoType avrdudeProgrammer! !

!ArduinoSketchUploader methodsFor: 'compiling and uploading' stamp: 'Richo 3/30/2010 13:57'!
uploadSketchNamed: sketchName onPort: portName uploadRate: uploadRate mcu: mcu fCpu: fCpu avrdudeProgrammer: programmerId 
	| sketchDirectory |
	sketchDirectory := self sketchesDirectory directoryNamed: sketchName.
	(self hasMakefile: sketchDirectory)
		ifFalse: [^ self error: 'No Makefile'].
	self
		waitFor: self timeoutSeconds
		untilFinish: [self
				executeUploadFor: sketchName
				onPort: portName
				uploadRate: uploadRate
				mcu: mcu
				fCpu: fCpu
				avrdudeProgrammer: programmerId]
		on: sketchDirectory! !

!ArduinoSketchUploader methodsFor: 'compiling and uploading' stamp: 'Richo 1/13/2010 17:25'!
waitFor: timeoutSeconds untilFinish: uploadBlock on: sketchDirectory 
	"Para asegurarme que el proceso haya terminado correctamente, espero
	hasta que en el directory del sketch exista un archivo llamado
	'finished' o se supere un determinado timeout"
	| delay timeout |
	timeout := timeoutSeconds.
	sketchDirectory
		deleteFileNamed: 'finished'
		ifAbsent: [].
	uploadBlock value.
	delay := Delay forSeconds: 1.
	[delay wait.
	timeout := timeout - 1]
		doWhileFalse: [timeout = 0
				or: [sketchDirectory fileExists: 'finished']].
	timeout = 0
		ifTrue: [^UploadingSketchError signal].
	self checkForErrorsOn: sketchDirectory! !

Object subclass: #ArduinoType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoType commentStamp: 'Richo 1/11/2010 15:49' prior: 0!
My subclasses represent different types of Arduino boards. I only implement class side methods with different constants for uploading sketches and stuff.!

ArduinoType subclass: #ArduinoATmega168
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoATmega168 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:53'!
fCpu
^16000000! !

!ArduinoATmega168 class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:55'!
friendlyNames
	^ {'ng or older w/ atmega168'}! !

!ArduinoATmega168 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:53'!
mcu
^'atmega168'! !

!ArduinoATmega168 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:53'!
uploadRate
^19200! !

ArduinoType subclass: #ArduinoATmega328
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoATmega328 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:01'!
fCpu
^16000000! !

!ArduinoATmega328 class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:54'!
friendlyNames
	^ {'duemilanove w/ atmega328'. 'nano w/ atmega328'}! !

!ArduinoATmega328 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:01'!
mcu
^'atmega328p'! !

!ArduinoATmega328 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:01'!
uploadRate
^57600! !

ArduinoType subclass: #ArduinoATmega8
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoATmega8 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:55'!
fCpu
^'16000000'! !

!ArduinoATmega8 class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:55'!
friendlyNames
	^ {'ng or older w/ atmega8'}! !

!ArduinoATmega8 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:55'!
mcu
^'atmega8'! !

!ArduinoATmega8 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:55'!
uploadRate
^19200! !

ArduinoType subclass: #ArduinoBT
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoBT class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:29'!
fCpu
^16000000! !

!ArduinoBT class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:55'!
friendlyNames
	^ {'bluetooth'}! !

!ArduinoBT class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:28'!
mcu
^'atmega168'! !

!ArduinoBT class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:29'!
uploadRate
^19200! !

ArduinoType subclass: #ArduinoDiecimila
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoDiecimila class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:06'!
fCpu
^16000000! !

!ArduinoDiecimila class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:56'!
friendlyNames
^{'diecimila w/ atmega168'. 'duemilanove w/ atmega168'. 'nano w/ atmega168'}! !

!ArduinoDiecimila class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:05'!
mcu
^'atmega168'! !

!ArduinoDiecimila class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:06'!
uploadRate
^19200! !

ArduinoType subclass: #ArduinoLilyPad
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoLilyPad class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:45'!
fCpu
^8000000! !

!ArduinoLilyPad class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:56'!
friendlyNames
	^ {'lilypad w/ atmega168'}! !

!ArduinoLilyPad class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:31'!
mcu
	^'atmega168'! !

!ArduinoLilyPad class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:45'!
uploadRate
^19200! !

ArduinoType subclass: #ArduinoLilyPad328
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoLilyPad328 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:30'!
fCpu
^8000000! !

!ArduinoLilyPad328 class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:56'!
friendlyNames
	^{ 'lilypad w/ atmega328'}! !

!ArduinoLilyPad328 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:30'!
mcu
^'atmega328p'! !

!ArduinoLilyPad328 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:30'!
uploadRate
^57600! !

ArduinoType subclass: #ArduinoMega
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoMega class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:18'!
fCpu
^16000000! !

!ArduinoMega class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:56'!
friendlyNames
	^{ 'mega'}! !

!ArduinoMega class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:18'!
mcu
^'atmega1280'! !

!ArduinoMega class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:18'!
uploadRate
^57600! !

ArduinoType subclass: #ArduinoMini
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoMini class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:27'!
fCpu
	^16000000! !

!ArduinoMini class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:56'!
friendlyNames
	^ {'mini'}! !

!ArduinoMini class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:26'!
mcu
	^'atmega168'! !

!ArduinoMini class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:27'!
uploadRate
	^19200! !

ArduinoType subclass: #ArduinoPro
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoPro class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:51'!
fCpu
^8000000! !

!ArduinoPro class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:57'!
friendlyNames
^{'pro w/ atmega168'. 'pro mini w/ atmega168'}! !

!ArduinoPro class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:51'!
mcu
^'atmega168'! !

!ArduinoPro class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:51'!
uploadRate
^19200! !

ArduinoType subclass: #ArduinoPro328
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-BoardTypes'!

!ArduinoPro328 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:47'!
fCpu
^8000000! !

!ArduinoPro328 class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 14:57'!
friendlyNames
	^ {'pro w/ atmega328'. 'pro mini w/ atmega328'}! !

!ArduinoPro328 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:47'!
mcu
^'atmega328p'! !

!ArduinoPro328 class methodsFor: 'as yet unclassified' stamp: 'Richo 12/29/2009 17:47'!
uploadRate
^57600! !

!ArduinoType class methodsFor: 'as yet unclassified' stamp: 'Richo 1/6/2010 17:56'!
allFriendlyNames
	| a |
	a := OrderedCollection new.
	self allTypes
		do: [:boardType | boardType friendlyNames
				do: [:friendlyName | a add: friendlyName asSymbol]].
	^ a asArray! !

!ArduinoType class methodsFor: 'as yet unclassified' stamp: 'Richo 1/5/2010 15:31'!
allTypes
^self allSubclasses! !

!ArduinoType class methodsFor: 'accessing' stamp: 'Richo 12/29/2009 17:19'!
avrdudeProgrammer
^'stk500'! !

!ArduinoType class methodsFor: 'accessing' stamp: 'Richo 12/29/2009 16:59'!
fCpu
^self subclassResponsibility ! !

!ArduinoType class methodsFor: 'accessing' stamp: 'Richo 1/6/2010 14:57'!
friendlyNames
	^ self subclassResponsibility! !

!ArduinoType class methodsFor: 'accessing' stamp: 'Richo 12/29/2009 16:59'!
mcu
^self subclassResponsibility ! !

!ArduinoType class methodsFor: 'accessing' stamp: 'Richo 12/29/2009 16:59'!
uploadRate
^self subclassResponsibility ! !

!ArduinoType class methodsFor: 'as yet unclassified' stamp: 'Richo 3/9/2010 12:59'!
withFriendlyName: aSymbol 
"Return an ArduinoType with the friendly name given as a parameter"

	^ (self allTypes
		select: [:each | each friendlyNames includes: aSymbol]) anyOne! !

Error subclass: #CompilingSketchError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-Uploading'!

Error subclass: #UploadingSketchError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Arduino-Compiler-Uploading'!

!UploadingSketchError commentStamp: 'Richo 1/11/2010 15:24' prior: 0!
I'm just an Error class indicating that a sketch was not successfully uploaded to the arduino board!
